@@ -1,4 +1,4 @@
 from .matrices import RowMatrix
-from .save import save
+from .save import save, pack, subset
 from .load import load, getdims, subtoind, indtosub
 from .datasets import DataSets
\ No newline at end of file
